%define rel 6

%bcond_without qt5
%bcond_without qt6

Name:           accounts-qt
Version:        1.16
Release:        %mkrel %{rel}
Summary:        Accounts framework Qt bindings
Group:          System/Libraries
License:        LGPLv2
URL:            https://gitlab.com/groups/accounts-sso
Source0:        https://gitlab.com/accounts-sso/libaccounts-qt/-/archive/VERSION_%{version}/lib%{name}-VERSION_%{version}.tar.bz2
Patch0:         0001-Support-for-provider-tags.patch
# Qt6 branch of Nicolas Fella's fork https://gitlab.com/nicolasfella/libaccounts-qt
Patch1:         0001-Fix-libaccounts-glib-includes.patch
Patch2:         0002-Port-away-from-deprecated-QList::toSet.patch
Patch3:         0003-Use-undeprecated-Account::value.patch
Patch4:         0004-Do-not-access-a-QString_out-of-bounds.patch
Patch5:         0005-Adjust-buildsystem-to-include-correct-Qt-Major-version-number.patch

BuildRequires:  pkgconfig(libaccounts-glib)
BuildRequires:  doxygen

%if %{with qt5}
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5Test)
%endif
%if %{with qt6}
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(Qt6Test)
%endif

%description
Framework to provide accounts for Qt.

#------------------------------------------------------------------------------
%if %{with qt5}

%define libaccounts_major 1
%define libaccounts_qt5 %mklibname accounts-qt5_ %{libaccounts_major}

%package -n     %{libaccounts_qt5}
Summary:        Runtime library for %{name}
Group:          System/Libraries

%description -n %{libaccounts_qt5}
Runtime libraries for %{name}.

%files -n %{libaccounts_qt5}
%{_libdir}/libaccounts-qt5.so.%{libaccounts_major}{,.*}

#---------------------------------------------------------------------------------

%define libaccounts_devel %mklibname accounts-qt5 -d

%package -n     %{libaccounts_devel}
Summary:        Headers files for %{name}
Group:          Development/KDE and Qt
Requires:       %{libaccounts_qt5} = %{version}-%{release}
Provides:       accounts-qt5-devel = %{version}-%{release}

%description -n %{libaccounts_devel}
Headers files for %{name}.

%files -n %{libaccounts_devel}
%{_includedir}/%{name}5/
%{_libdir}/libaccounts-qt5.so
%{_libdir}/cmake/AccountsQt5/
%{_libdir}/pkgconfig/accounts-qt5.pc
%{_bindir}/accountstest
%endif

#------------------------------------------------------------------------------
%if %{with qt6}

%define libaccountsqt6_major 1
%define libaccounts_qt6 %mklibname accounts-qt6_ %{libaccountsqt6_major}

%package -n     %{libaccounts_qt6}
Summary:        Runtime library for %{name}
Group:          System/Libraries

%description -n %{libaccounts_qt6}
Runtime libraries for %{name}.

%files -n %{libaccounts_qt6}
%{_libdir}/libaccounts-qt6.so.%{libaccountsqt6_major}{,.*}

#---------------------------------------------------------------------------------

%define libaccountsqt6_devel %mklibname accounts-qt6 -d

%package -n     %{libaccountsqt6_devel}
Summary:        Headers files for %{name}
Group:          Development/KDE and Qt
Requires:       %{libaccounts_qt6} = %{version}-%{release}
Provides:       accounts-qt6-devel = %{version}-%{release}

%description -n %{libaccountsqt6_devel}
Headers files for %{name}.

%files -n %{libaccountsqt6_devel}
%{_includedir}/%{name}6/
%{_libdir}/libaccounts-qt6.so
%{_libdir}/cmake/AccountsQt6/
%{_libdir}/pkgconfig/accounts-qt6.pc
%endif

#------------------------------------------------------------------------------

%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    doc
Documentation for %{name}.

%files doc
%{_datadir}/doc/%{name}

#---------------------------------------------------------------------------------

%prep
%autosetup -p1 -n lib%{name}-VERSION_%{version}

sed -i 's|$${TOP_BUILD_DIR}/Accounts|../Accounts|' tests/tst_libaccounts.pro

mkdir -p qt5
mv $(ls |grep -v qt5) qt5/
cp -a qt5 qt6

%build
%if %{with qt5}
pushd qt5
%qmake_qt5 \
	QMF_INSTALL_ROOT=%{_prefix} \
	CONFIG+=release accounts-qt.pro \
	LIBDIR=%{_libdir} \
	TOP_SRC_DIR=..

%make_build
popd
%endif

%if %{with qt6}
pushd qt6
%qmake_qt6 \
	QMF_INSTALL_ROOT=%{_prefix} \
	CONFIG+=release accounts-qt.pro \
	LIBDIR=%{_libdir} \
	TOP_SRC_DIR=..

%make_build
popd
%endif

%install
%if %{with qt5}
%make_install -C qt5 INSTALL_ROOT=%{buildroot}
%endif

%if %{with qt6}
%make_install -C qt6 INSTALL_ROOT=%{buildroot}
%endif


%changelog
* Wed Jan 10 2024 daviddavid <daviddavid> 1.16-6.mga10
+ Revision: 2029505
- switch to the Qt6 branch of Nicolas Fella's fork (as recommend KDE)
  * https://gitlab.com/nicolasfella/libaccounts-qt

* Wed Nov 15 2023 daviddavid <daviddavid> 1.16-5.mga10
+ Revision: 2006827
- add Qt6 support
- backport upstream patch to fix libaccounts-glib includes
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- revert the rpath check disable

* Wed Mar 09 2022 mrambo3501 <mrambo3501> 1.16-3.mga9
+ Revision: 1790093
- disable rpath checking

* Wed Dec 16 2020 umeabot <umeabot> 1.16-2.mga8
+ Revision: 1658123
- Rebuild for new Qt5

* Wed Apr 22 2020 daviddavid <daviddavid> 1.16-1.mga8
+ Revision: 1570685
- new version: 1.16
- rebuild for new libaccounts-glib 1.25
- update Source URL
- fix library and devel pkg names

* Sat Feb 15 2020 umeabot <umeabot> 1.15-5.mga8
+ Revision: 1524273
- Mageia 8 Mass Rebuild

* Fri Mar 29 2019 umeabot <umeabot> 1.15-4.mga7
+ Revision: 1381205
- Qt5 Rebuild

* Tue Jan 15 2019 daviddavid <daviddavid> 1.15-3.mga7
+ Revision: 1356957
- rebuild for new libaccounts-glib 1.24

* Sun Sep 23 2018 umeabot <umeabot> 1.15-2.mga7
+ Revision: 1297273
- Mageia 7 Mass Rebuild

* Fri Mar 23 2018 kekepower <kekepower> 1.15-1.mga7
+ Revision: 1211450
- Update to version 1.15

* Sat Feb 13 2016 umeabot <umeabot> 1.13-2.mga6
+ Revision: 959476
- Mageia 6 Mass Rebuild
+ luigiwalser <luigiwalser>
- update URL

* Tue Jul 07 2015 neoclust <neoclust> 1.13-1.mga6
+ Revision: 852408
- Fix BRs
- New version

* Wed Oct 15 2014 umeabot <umeabot> 1.11-4.mga5
+ Revision: 750958
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.11-3.mga5
+ Revision: 686444
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.11-2.mga5
+ Revision: 677682
- Mageia 5 Mass Rebuild

* Mon Aug 25 2014 lmenut <lmenut> 1.11-1.mga5
+ Revision: 667397
- Update to 1.11
  fix files list

* Mon Oct 21 2013 umeabot <umeabot> 1.9-2.mga4
+ Revision: 540950
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 mikala <mikala> 1.9-1.mga4
+ Revision: 494571
- imported package accounts-qt

